// SPDX-FileCopyrightText: 2022 Matteo Settenvini <matteo.settenvini@montecristosoftware.eu>
// SPDX-License-Identifier: AGPL-3.0-or-later

pub mod credentials;

use {
    self::credentials::Credentials,
    anyhow::Result,
    directories::ProjectDirs,
    serde::Deserialize,
    std::io::{Error, ErrorKind},
    std::path::PathBuf,
};

#[derive(Deserialize)]
pub struct Config {
    #[serde(skip_deserializing)]
    pub credentials: Credentials,
}

impl Config {
    pub fn new() -> Self {
        let config_dir = Self::ensure_config_dir().unwrap();
        Config {
            credentials: Credentials::from_directory(&config_dir).unwrap(),
        }
    }

    fn ensure_config_dir() -> Result<PathBuf> {
        let config_dir = ProjectDirs::from("eu", "montecristosoftware", "cooking-schedule")
            .ok_or(Error::new(
                ErrorKind::Other,
                "Unable to determine application configuration folder",
            ))?
            .config_dir()
            .to_path_buf();
        std::fs::create_dir_all(&config_dir)?;
        Ok(config_dir)
    }
}
